@@ -57,9 +57,10 @@
 #include "ChartTypeHelper.hxx"
 #include "ObjectNameProvider.hxx"
 #include "DiagramHelper.hxx"
-#include "chartview/NumberFormatterWrapper.hxx"
+#include "NumberFormatterWrapper.hxx"
 #include "AxisIndexDefines.hxx"
 #include "AxisHelper.hxx"
+#include "ExplicitCategoriesProvider.hxx"
 
 #include <com/sun/star/chart2/XAxis.hpp>
 #include <com/sun/star/chart2/XChartType.hpp>
@@ -117,6 +118,7 @@ ObjectPropertiesDialogParameter::ObjectPropertiesDialogParameter( const rtl::OUS
         , m_bIsCrossingAxisIsCategoryAxis(false)
         , m_aCategories()
         , m_xChartDocument( 0 )
+        , m_bComplexCategoriesAxis( false )
 {
     rtl::OUString aParticleID = ObjectIdentifier::getParticleID( m_aObjectCID );
     m_bAffectsMultipleObjects = aParticleID.equals(C2U("ALLELEMENTS"));
@@ -180,7 +182,7 @@ void ObjectPropertiesDialogParameter::init( const uno::Reference< frame::XModel
                 ScaleData aData( xAxis->getScaleData() );
                 if( chart2::AxisType::SERIES == aData.AxisType )
                     m_bHasScaleProperties = false;
-                if( chart2::AxisType::REALNUMBER == aData.AxisType || chart2::AxisType::PERCENT == aData.AxisType )
+                if( chart2::AxisType::SERIES != aData.AxisType )
                     m_bHasNumberProperties = true;
 
                 sal_Int32 nCooSysIndex=0;
@@ -207,6 +209,13 @@ void ObjectPropertiesDialogParameter::init( const uno::Reference< frame::XModel
                     if( m_bIsCrossingAxisIsCategoryAxis )
                         m_aCategories = DiagramHelper::getExplicitSimpleCategories( Reference< chart2::XChartDocument >( xChartModel, uno::UNO_QUERY) );
                 }
+
+                m_bComplexCategoriesAxis = false;
+                if ( nDimensionIndex == 0 && aData.AxisType == chart2::AxisType::CATEGORY )
+                {
+                    ExplicitCategoriesProvider aExplicitCategoriesProvider( xCooSys, xChartModel ); 
+                    m_bComplexCategoriesAxis = aExplicitCategoriesProvider.hasComplexCategories();
+                }
             }
         }
 
@@ -323,9 +332,12 @@ uno::Reference< chart2::XChartDocument > ObjectPropertiesDialogParameter::getDoc
 {
     return m_xChartDocument;
 }
+bool ObjectPropertiesDialogParameter::IsComplexCategoriesAxis() const
+{
+    return m_bComplexCategoriesAxis;
+}
 
-//const USHORT nNoArrowDlg          = 1100;
-const USHORT nNoArrowNoShadowDlg    = 1101;
+const sal_uInt16 nNoArrowNoShadowDlg    = 1101;
 
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
@@ -506,7 +518,7 @@ SchAttribTabDlg::~SchAttribTabDlg()
     delete m_pAutoSymbolGraphic;
 }
 
-void SchAttribTabDlg::PageCreated(USHORT nId, SfxTabPage &rPage)
+void SchAttribTabDlg::PageCreated(sal_uInt16 nId, SfxTabPage &rPage)
 {
     SfxAllItemSet aSet(*(GetInputSetImpl()->GetPool()));
     switch (nId)
@@ -529,7 +541,6 @@ void SchAttribTabDlg::PageCreated(USHORT nId, SfxTabPage &rPage)
                     aSet.Put(SvxGraphicItem(SID_GRAPHIC,*m_pAutoSymbolGraphic));
             }
             rPage.PageCreated(aSet);
-            //rPage.ActivatePage(*GetInputSetImpl()); //what for?
             break;
 
         case RID_SVXPAGE_AREA:
@@ -540,7 +551,6 @@ void SchAttribTabDlg::PageCreated(USHORT nId, SfxTabPage &rPage)
             aSet.Put(SfxUInt16Item(SID_PAGE_TYPE,nPageType));
             aSet.Put(SfxUInt16Item(SID_DLG_TYPE,nDlgType));
             rPage.PageCreated(aSet);
-            //rPage.ActivatePage(*GetInputSetImpl()); //what for?
             break;
 
         case RID_SVXPAGE_TRANSPARENCE:
@@ -564,6 +574,7 @@ void SchAttribTabDlg::PageCreated(USHORT nId, SfxTabPage &rPage)
         {
             bool bShowStaggeringControls = m_pParameter->CanAxisLabelsBeStaggered();
             ((SchAxisLabelTabPage&)rPage).ShowStaggeringControls( bShowStaggeringControls );
+            ( dynamic_cast< SchAxisLabelTabPage& >( rPage ) ).SetComplexCategories( m_pParameter->IsComplexCategoriesAxis() );
             break;
         }
 
@@ -607,7 +618,7 @@ void SchAttribTabDlg::PageCreated(USHORT nId, SfxTabPage &rPage)
             break;
 
         case RID_SVXPAGE_NUMBERFORMAT:
-               aSet.Put (SvxNumberInfoItem( m_pNumberFormatter, (const USHORT)SID_ATTR_NUMBERFORMAT_INFO));
+               aSet.Put (SvxNumberInfoItem( m_pNumberFormatter, (const sal_uInt16)SID_ATTR_NUMBERFORMAT_INFO));
             rPage.PageCreated(aSet);
             break;
 
